==> haskell-extra-1.5.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.5.1
id: extra-1.5.1-HeeVckCVl1V9DE6lYqg83I
key: extra-1.5.1-HeeVckCVl1V9DE6lYqg83I
license: BSD3
copyright: Neil Mitchell 2014-2016
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Extra Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.Tuple.Extra Data.Typeable.Extra
    Data.Version.Extra Numeric.Extra System.Directory.Extra
    System.Environment.Extra System.Info.Extra System.IO.Extra
    System.Process.Extra System.Time.Extra
abi: c577dc6d23c2c5be270336de7ec18349
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/extra-1.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/extra-1.5.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/extra-1.5.1
hs-libraries: HSextra-1.5.1-HeeVckCVl1V9DE6lYqg83I
depends:
    base-4.9.0.0 clock-0.7.2-bxVecpUqndAMeayDi5R9Y directory-1.2.6.2
    filepath-1.4.1.0 process-1.4.2.0 time-1.6.0.1 unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-extra-1.5.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.5.2
id: extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
key: extra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
license: BSD3
copyright: Neil Mitchell 2014-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Extra Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.Tuple.Extra Data.Typeable.Extra
    Data.Version.Extra Numeric.Extra System.Directory.Extra
    System.Environment.Extra System.Info.Extra System.IO.Extra
    System.Process.Extra System.Time.Extra
abi: d29446798af92a9cb1aafbc3d9235c39
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/extra-1.5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/extra-1.5.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/extra-1.5.2
hs-libraries: HSextra-1.5.2-FWjov7JFxoq2wD5IPaMEgG
depends:
    base-4.9.0.0 clock-0.7.2-bxVecpUqndAMeayDi5R9Y directory-1.2.6.2
    filepath-1.4.1.0 process-1.4.2.0 time-1.6.0.1 unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
